.. _hyperspy_as_library-examples-index:

##############################################
hyperspy_as_library Examples
##############################################

.. htmlonly::

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 1

    curve_fitting_data <curve_fitting_data.rst>
    minimal_example <minimal_example.rst>
